import React, { useEffect, useState } from 'react'
import { AppBar, Box, Button, CircularProgress, Dialog, IconButton, Toolbar, Typography } from '@mui/material';
import { ChevronLeft, ChevronRight, Close } from '@mui/icons-material';
import { useDownload } from '../../hooks/swrHooks';
import { fileTypeFromBlob } from 'file-type/core';

interface Props {
    open: boolean;
    setOpen: (state: boolean) => void;
    docs: any;
    currentFileNo: number;
    setCurrentFileNo: (state: number) => void;
}

export default function FileViewer({
    open,
    setOpen,
    docs,
    currentFileNo,
    setCurrentFileNo
}: Props) {
    const { file, isError, isLoading } = useDownload(currentFileNo >= 0 ? docs[currentFileNo]?.document_folder_id : null, currentFileNo >= 0 ? docs[currentFileNo]?.id : null)

    const [fileType, setFileType] = useState<any>("")

    const getFileType = async (file: any) => {
        try {
            await fileTypeFromBlob(file).then(response => {
                setFileType(response)
            })
        } catch (error) {
            console.error(error)
        }
    }

    useEffect(() => {
        if (!isLoading && file) {
            getFileType(file)
        }
    }, [isLoading])

    const handleSave = async () => {
        const url = window.URL.createObjectURL(file)
        const link = document.createElement('a')
        link.href = url
        link.setAttribute('download', docs[currentFileNo].name)
        document.body.appendChild(link)
        link.click()
        link.remove()
    }

    return (
        <Dialog
            fullScreen
            open={open}
            onClose={() => {
                setOpen(false)
                setCurrentFileNo(-1)
            }}
            aria-labelledby="modal-modal-title"
            aria-describedby="modal-modal-description"
        >
            <AppBar sx={{ position: 'relative' }}>
                <Toolbar>
                    <IconButton
                        edge="start"
                        color="inherit"
                        onClick={() => {
                            setOpen(false)
                            setCurrentFileNo(-1)
                        }}
                        aria-label="close"
                    >
                        <Close />
                    </IconButton>

                    <Typography sx={{ ml: 2, flex: 1 }} variant="h6" component="div">
                        {currentFileNo != -1 && docs[currentFileNo].name}
                    </Typography>

                    <div>
                        <IconButton
                            color='inherit'
                            onClick={() => {
                                if (currentFileNo >= 0 && currentFileNo > 0) {
                                    setCurrentFileNo(currentFileNo - 1)
                                }
                            }}
                            disabled={currentFileNo >= 0 && currentFileNo === 0}
                        >
                            <ChevronLeft />
                        </IconButton>
                        
                        <IconButton
                            color='inherit'
                            onClick={() => {
                                if (currentFileNo >= 0 && currentFileNo < docs.length) {
                                    setCurrentFileNo(currentFileNo + 1)
                                }
                            }}
                            disabled={currentFileNo >= 0 && currentFileNo >= docs.length - 1}
                        >
                            <ChevronRight />
                        </IconButton>
                    </div>

                    <Button
                        autoFocus
                        color="inherit"
                        onClick={handleSave}
                    >
                        Сохранить
                    </Button>
                </Toolbar>
            </AppBar>
            <Box>
                {file && <img src={window.URL.createObjectURL(file)} />}
            </Box>
        </Dialog>
    )
}